@@ -21,37 +21,20 @@ Pygal -  A python svg graph plotting library
 
 """
 
-__version__ = '0.10.3'
-
+__version__ = '0.13.0'
+import sys
 from pygal.config import Config
-from pygal.graph.bar import Bar
-from pygal.graph.dot import Dot
-from pygal.graph.funnel import Funnel
-from pygal.graph.gauge import Gauge
-from pygal.graph.horizontal import HorizontalBar
-from pygal.graph.horizontal import HorizontalStackedBar
-from pygal.graph.line import Line
-from pygal.graph.pie import Pie
-from pygal.graph.pyramid import Pyramid
-from pygal.graph.radar import Radar
-from pygal.graph.stackedbar import StackedBar
-from pygal.graph.stackedline import StackedLine
-from pygal.graph.xy import XY
+from pygal.ghost import Ghost
+from pygal.graph import CHARTS_NAMES
+
+CHARTS = []
+CHARTS_BY_NAME = {}
+
+for NAME in CHARTS_NAMES:
+    _CHART = type(NAME, (Ghost,), {})
+    CHARTS.append(_CHART)
+    CHARTS_BY_NAME[NAME] = _CHART
+    setattr(sys.modules[__name__], NAME, _CHART)
 
 
-#: List of all chart types
-CHARTS = [
-    Bar,
-    Dot,
-    Funnel,
-    Gauge,
-    HorizontalBar,
-    HorizontalStackedBar,
-    Line,
-    Pie,
-    Pyramid,
-    Radar,
-    StackedBar,
-    StackedLine,
-    XY
-]
+__all__ = CHARTS_NAMES + [Config.__name__, 'CHARTS', 'CHARTS_BY_NAME']
