@@ -20,3 +20,20 @@
 Graph modules
 
 """
+
+CHARTS_NAMES = [
+    'Line',
+    'StackedLine',
+    'XY',
+    'Bar',
+    'HorizontalBar',
+    'StackedBar',
+    'HorizontalStackedBar',
+    'Pie',
+    'Radar',
+    'Funnel',
+    'Pyramid',
+    'VerticalPyramid',
+    'Dot',
+    'Gauge'
+]
