@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+ # -*- coding: utf-8 -*-
 # This file is part of pygal
 #
 # A python svg graph plotting library
@@ -22,48 +22,38 @@ Base for pygal charts
 """
 
 from __future__ import division
-import io
-from pygal.serie import Serie, Value
 from pygal.view import Margin, Box
 from pygal.util import (
     get_text_box, get_texts_box, cut, rad, humanize, truncate)
 from pygal.svg import Svg
-from pygal.config import Config
-from pygal.util import cached_property
-from math import sin, cos, sqrt
+from pygal.util import cached_property, reverse_text_len
+from math import sin, cos, sqrt, ceil
 
 
 class BaseGraph(object):
     """Graphs commons"""
 
-    __value__ = Value
+    _adapters = []
 
-    def __init__(self, config=None, **kwargs):
+    def __init__(self, config, series):
         """Init the graph"""
-        self.config = config or Config()
-        self.config(**kwargs)
+        self.config = config
+        self.series = series or []
         self.horizontal = getattr(self, 'horizontal', False)
         self.svg = Svg(self)
-        self.series = []
         self._x_labels = None
         self._y_labels = None
-        self._box = None
         self.nodes = {}
-        self.margin = None
-        self.view = None
-
-    def add(self, title, values):
-        """Add a serie to this graph"""
-        self.series.append(
-            Serie(title, values, len(self.series), self.__value__))
-
-    def reinit(self):
-        """(Re-)Init the graph"""
         self.margin = Margin(*([20] * 4))
         self._box = Box()
+        self.view = None
         if self.logarithmic and self.zero == 0:
-            # If logarithmic, default zero to 1
-            self.zero = 1
+            # Explicit min to avoid interpolation dependency
+            self.zero = min(filter(
+                lambda x: x > 0,
+                [val for serie in self.series for val in serie.safe_values]))
+        self._draw()
+        self.svg.pre_render()
 
     def __getattr__(self, attr):
         """Search in config, then in self"""
@@ -71,6 +61,22 @@ class BaseGraph(object):
             return object.__getattribute__(self.config, attr)
         return object.__getattribute__(self, attr)
 
+    def _split_title(self):
+        if not self.title:
+            self.title = []
+            return
+        size = reverse_text_len(self.width, self.title_font_size)
+        title = self.title.strip()
+        self.title = []
+        while len(title) > size:
+            title_part = title[:size]
+            i = title_part.rfind(' ')
+            if i == -1:
+                i = len(title_part)
+            self.title.append(title_part[:i])
+            title = title[i:].strip()
+        self.title.append(title)
+
     @property
     def _format(self):
         """Return the value formatter for this graph"""
@@ -84,21 +90,21 @@ class BaseGraph(object):
 
     def _compute_margin(self):
         """Compute graph margins from set texts"""
-        if self.show_legend:
+        if self.show_legend and self.series:
             h, w = get_texts_box(
                 map(lambda x: truncate(x, self.truncate_legend or 15),
-                  cut(self.series, 'title')),
+                    cut(self.series, 'title')),
                 self.legend_font_size)
             if self.legend_at_bottom:
                 h_max = max(h, self.legend_box_size)
                 self.margin.bottom += 10 + h_max * round(
-                        sqrt(len(self.series)) - 1) * 1.5 + h_max
+                    sqrt(self._order) - 1) * 1.5 + h_max
             else:
                 self.margin.right += 10 + w + self.legend_box_size
 
         if self.title:
-            h, w = get_text_box(self.title, self.title_font_size)
-            self.margin.top += 10 + h
+            h, _ = get_text_box(self.title[0], self.title_font_size)
+            self.margin.top += len(self.title) * (10 + h)
 
         if self._x_labels:
             h, w = get_texts_box(
@@ -129,105 +135,52 @@ class BaseGraph(object):
         return [val
                 for serie in self.series
                 for val in serie.values
-                if val != None]
+                if val is not None]
 
     @cached_property
     def _len(self):
         """Getter for the maximum series size"""
-        return max([len(serie.values) for serie in self.series])
+        return max([len(serie.values) for serie in self.series] or [0])
 
     @cached_property
     def _min(self):
         """Getter for the minimum series value"""
-        return (self.range and self.range[0]) or min(self._values)
+        return (self.range and self.range[0]) or (
+            min(self._values) if self._values else None)
 
     @cached_property
     def _max(self):
         """Getter for the maximum series value"""
-        return (self.range and self.range[1]) or max(self._values)
+        return (self.range and self.range[1]) or (
+            max(self._values) if self._values else None)
+
+    @cached_property
+    def _order(self):
+        """Getter for the maximum series value"""
+        return len(self.series)
 
     def _draw(self):
         """Draw all the things"""
-        self._prepare_data()
         self._compute()
+        self._split_title()
         self._compute_margin()
         self._decorate()
-        self._plot()
+        if self.series and self._has_data():
+            self._plot()
+        else:
+            self.svg.draw_no_data()
 
     def _has_data(self):
         """Check if there is any data"""
-        if len(self.series) == 0:
-            return False
-        if sum(map(len, map(lambda s: s.values, self.series))) == 0:
-            return False
-        return True
+        return sum(
+            map(len, map(lambda s: s.safe_values, self.series))) != 0 and (
+                sum(map(abs, self._values)) != 0)
 
-    def _prepare_data(self):
-        """Remove aberrant values"""
-        if self.logarithmic:
-            for serie in self.series:
-                for metadata in serie.metadata:
-                    if metadata.value <= 0:
-                        metadata.value = None
-
-    def _uniformize_data(self):
-        """Make all series to max len"""
-        for serie in self.series:
-            if len(serie.values) < self._len:
-                diff = self._len - len(serie.values)
-                serie.metadata += diff * [self.__value__(0)]
-
-            for metadata in serie.metadata:
-                if metadata.value == None:
-                    metadata.value = 0
-
-    def _render(self):
-        """Make the graph internally"""
-        self.reinit()
-        self.svg.reinit()
-        if self._has_data():
-            self._draw()
-            self.svg.pre_render(False)
-        else:
-            self.svg.pre_render(True)
-
-    def render(self, is_unicode=False):
+    def render(self, is_unicode):
         """Render the graph, and return the svg string"""
-        self._render()
         return self.svg.render(
             is_unicode=is_unicode, pretty_print=self.pretty_print)
 
     def render_tree(self):
         """Render the graph, and return lxml tree"""
-        self._render()
         return self.svg.root
-
-    def render_pyquery(self):
-        """Render the graph, and return a pyquery wrapped tree"""
-        from pyquery import PyQuery as pq
-        return pq(self.render_tree())
-
-    def render_in_browser(self):
-        """Render the graph, open it in your browser with black magic"""
-        from lxml.html import open_in_browser
-        open_in_browser(self.render_tree(), encoding='utf-8')
-
-    def render_response(self):
-        """Render the graph, and return a Flask response"""
-        from flask import Response
-        return Response(self.render(), mimetype='image/svg+xml')
-
-    def render_to_file(self, filename):
-        """Render the graph, and write it to filename"""
-        with io.open(filename, 'w', encoding='utf-8') as f:
-            f.write(self.render(is_unicode=True))
-
-    def render_to_png(self, filename):
-        """Render the graph, convert it to png and write it to filename"""
-        import cairosvg
-        from io import BytesIO
-        fakefile = BytesIO()
-        fakefile.write(self.render())
-        fakefile.seek(0)
-        cairosvg.surface.PNGSurface.convert(
-            file_obj=fakefile, write_to=filename)
