@@ -23,16 +23,16 @@ Radar chart
 
 from __future__ import division
 from pygal.graph.line import Line
-from pygal.serie import PositiveValue
-from pygal.view import PolarView
-from pygal.util import deg, cached_property, compute_scale
+from pygal.adapters import positive, none_to_zero
+from pygal.view import PolarView, PolarLogView
+from pygal.util import deg, cached_property, compute_scale, is_major
 from math import cos, pi
 
 
 class Radar(Line):
     """Kiviat graph"""
 
-    __value__ = PositiveValue
+    _adapters = [positive, none_to_zero]
 
     def __init__(self, *args, **kwargs):
         self.x_pos = None
@@ -54,7 +54,12 @@ class Radar(Line):
             return super(Line, self)._values
 
     def _set_view(self):
-        self.view = PolarView(
+        if self.logarithmic:
+            view_class = PolarLogView
+        else:
+            view_class = PolarView
+
+        self.view = view_class(
             self.width - self.margin.x,
             self.height - self.margin.y,
             self._box)
@@ -70,15 +75,16 @@ class Radar(Line):
         for label, theta in self._x_labels:
             guides = self.svg.node(axis, class_='guides')
             end = self.view((r, theta))
-            self.svg.node(guides, 'path',
-                      d='M%s L%s' % (format_(center), format_(end)),
-                      class_='line')
+            self.svg.node(
+                guides, 'path',
+                d='M%s L%s' % (format_(center), format_(end)),
+                class_='line')
             r_txt = (1 - self._box.__class__.margin) * self._box.ymax
             pos_text = self.view((r_txt, theta))
-            text = self.svg.node(guides, 'text',
-                      x=pos_text[0],
-                      y=pos_text[1]
-            )
+            text = self.svg.node(
+                guides, 'text',
+                x=pos_text[0],
+                y=pos_text[1])
             text.text = label
             angle = - theta + pi / 2
             if cos(angle) < 0:
@@ -93,25 +99,28 @@ class Radar(Line):
         axis = self.svg.node(self.nodes['plot'], class_="axis y web")
 
         for label, r in reversed(self._y_labels):
+            major = is_major(r)
             guides = self.svg.node(axis, class_='guides')
             self.svg.line(
                 guides, [self.view((r, theta)) for theta in self.x_pos],
                 close=True,
-                class_='guide line')
+                class_='%sguide line' % (
+                    'major ' if major else ''))
             x, y = self.view((r, self.x_pos[0]))
-            self.svg.node(guides, 'text',
-                             x=x - 5,
-                             y=y
+            self.svg.node(
+                guides, 'text',
+                x=x - 5,
+                y=y,
+                class_='major' if major else ''
             ).text = label
 
     def _compute(self):
-        delta = 2 * pi / self._len
+        delta = 2 * pi / self._len if self._len else 0
         x_pos = [.5 * pi + i * delta for i in range(self._len + 1)]
         for serie in self.series:
-            vals = [val if val != None else 0 for val in serie.values]
             serie.points = [
                 (v, x_pos[i])
-                for i, v in enumerate(vals)]
+                for i, v in enumerate(serie.values)]
             if self.interpolate:
                 extend = 2
                 extended_x_pos = (
@@ -119,17 +128,23 @@ class Radar(Line):
                     x_pos +
                     [.5 * pi + i * delta for i in range(
                         self._len + 1, self._len + 1 + extend)])
-                extended_vals = vals[-extend:] + vals + vals[:extend]
+                extended_vals = (serie.values[-extend:] +
+                                 serie.values +
+                                 serie.values[:extend])
                 serie.interpolated = self._interpolate(
                     extended_vals, extended_x_pos, polar=True)
 
+        # x labels space
         self._box.margin *= 2
-        self._box.xmin = self._box.ymin = - self._max
-        self._box.xmax = self._box.ymax = self._rmax = self._max
+        self._rmin = self.zero
+        self._rmax = self._max or 1
+        self._box.set_polar_box(self._rmin, self._rmax)
 
         y_pos = compute_scale(
-            0, self._box.ymax, self.logarithmic, self.order_min, max_scale=8
+            self._rmin, self._rmax, self.logarithmic, self.order_min,
+            max_scale=8
         ) if not self.y_labels else map(int, self.y_labels)
+
         self._x_labels = self.x_labels and zip(self.x_labels, x_pos)
         self._y_labels = zip(map(self._format, y_pos), y_pos)
 
