@@ -20,14 +20,16 @@
 Stacked Line chart
 
 """
-
+from __future__ import division
 from pygal.graph.line import Line
-from itertools import izip_longest
+from pygal.adapters import none_to_zero
 
 
 class StackedLine(Line):
     """Stacked Line graph"""
 
+    _adapters = [none_to_zero]
+
     def __init__(self, *args, **kwargs):
         self._previous_line = None
         super(StackedLine, self).__init__(*args, **kwargs)
@@ -40,10 +42,7 @@ class StackedLine(Line):
         self._previous_line = values
         return new_values
 
-    def _compute(self):
-        self._uniformize_data()
-        x_pos = [x / float(self._len - 1) for x in range(self._len)
-        ] if self._len != 1 else [.5]  # Center if only one value
+    def _points(self, x_pos):
         accumulation = [0] * self._len
         for serie in self.series:
             accumulation = map(sum, zip(accumulation, serie.values))
@@ -52,4 +51,3 @@ class StackedLine(Line):
                 for i, v in enumerate(accumulation)]
             if self.interpolate:
                 serie.interpolated = self._interpolate(accumulation, x_pos)
-        return super(StackedLine, self)._compute()
