@@ -73,8 +73,9 @@ def test_format():
     obj.a = 1
     obj.b = True
     obj.c = '3'
-    assert template('foo {{ o.a }} {{o.b}}-{{o.c}}',
-               o=obj) == 'foo 1 True-3'
+    assert template(
+        'foo {{ o.a }} {{o.b}}-{{o.c}}',
+        o=obj) == 'foo 1 True-3'
 
 
 def test_humanize():
@@ -125,7 +126,7 @@ def test_truncate():
 
 def test_minify_css():
     css = '''
-/* 
+/*
  * Font-sizes from config, override with care
  */
 
@@ -136,7 +137,7 @@ def test_minify_css():
 }
 
 .legends .legend text {
-  font-family: monospace; 
+  font-family: monospace;
   font-size: 14 ;}
 '''
     assert minify_css(css) == (
